@@ -14,13 +14,14 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2011 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2012 Live Networks, Inc.  All rights reserved.
 // A filter that breaks up a H.264 Video Elementary Stream into NAL units.
 // Implementation
 
 #include "H264VideoStreamFramer.hh"
 #include "MPEGVideoStreamParser.hh"
 #include "BitVector.hh"
+#include "H264VideoRTPSource.hh" // for "parseSPropParameterSets()"
 
 ////////// H264VideoStreamParser definition //////////
 
@@ -87,6 +88,21 @@ H264VideoStreamFramer::~H264VideoStreamFramer() {
   delete[] fLastSeenPPS;
 }
 
+void H264VideoStreamFramer::setSPSandPPS(char const* sPropParameterSetsStr) {
+  unsigned numSPropRecords;
+  SPropRecord* sPropRecords = parseSPropParameterSets(sPropParameterSetsStr, numSPropRecords);
+  for (unsigned i = 0; i < numSPropRecords; ++i) {
+    if (sPropRecords[i].sPropLength == 0) continue; // bad data
+    u_int8_t nal_unit_type = (sPropRecords[i].sPropBytes[0])&0x1F;
+    if (nal_unit_type == 7/*SPS*/) {
+      saveCopyOfSPS(sPropRecords[i].sPropBytes, sPropRecords[i].sPropLength);
+    } else if (nal_unit_type == 8/*PPS*/) {
+      saveCopyOfPPS(sPropRecords[i].sPropBytes, sPropRecords[i].sPropLength);
+    }
+  }
+  delete[] sPropRecords;
+}
+
 void H264VideoStreamFramer::saveCopyOfSPS(u_int8_t* from, unsigned size) {
   delete[] fLastSeenSPS;
   fLastSeenSPS = new u_int8_t[size];
@@ -328,7 +344,7 @@ void H264VideoStreamParser
     DEBUG_PRINT(chroma_format_idc);
     if (chroma_format_idc == 3) {
       DEBUG_TAB;
-      separate_colour_plane_flag = bv.get1Bit();
+      separate_colour_plane_flag = bv.get1BitBoolean();
       DEBUG_PRINT(separate_colour_plane_flag);
     }
     (void)bv.get_expGolomb(); // bit_depth_luma_minus8
@@ -392,7 +408,7 @@ void H264VideoStreamParser
   DEBUG_PRINT(pic_width_in_mbs_minus1);
   unsigned pic_height_in_map_units_minus1 = bv.get_expGolomb();
   DEBUG_PRINT(pic_height_in_map_units_minus1);
-  frame_mbs_only_flag = bv.get1Bit();
+  frame_mbs_only_flag = bv.get1BitBoolean();
   DEBUG_PRINT(frame_mbs_only_flag);
   if (!frame_mbs_only_flag) {
     bv.skipBits(1); // mb_adaptive_frame_field_flag
@@ -521,11 +537,11 @@ void H264VideoStreamParser
   DEBUG_PRINT(frame_num);
   if (!frame_mbs_only_flag) {
     DEBUG_TAB;
-    field_pic_flag = bv.get1Bit();
+    field_pic_flag = bv.get1BitBoolean();
     DEBUG_PRINT(field_pic_flag);
     if (field_pic_flag) {
       DEBUG_TAB;
-      bottom_field_flag = bv.get1Bit();
+      bottom_field_flag = bv.get1BitBoolean();
       DEBUG_PRINT(bottom_field_flag);
     }
   }
@@ -562,7 +578,7 @@ unsigned H264VideoStreamParser::parse() {
       fHaveSeenFirstStartCode = True; // from now on
     }
     
-    if (fOutputStartCodeSize > 0) {
+    if (fOutputStartCodeSize > 0 && curFrameSize() == 0) {
       // Include a start code in the output:
       save4Bytes(0x00000001);
     }
@@ -685,7 +701,7 @@ unsigned H264VideoStreamParser::parse() {
 #endif
 	  thisNALUnitEndsAccessUnit = True;
 	} else {
-	  // The next NAL unit is also a VLC.  We need to examine it a little to figure out if it's a different 'access unit'.
+	  // The next NAL unit is also a VCL.  We need to examine it a little to figure out if it's a different 'access unit'.
 	  // (We use many of the criteria described in section 7.4.1.2.4 of the H.264 specification.)
 	  Boolean IdrPicFlag = nal_unit_type == 5;
 	  Boolean next_IdrPicFlag = next_nal_unit_type == 5;
