@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2011 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2012 Live Networks, Inc.  All rights reserved.
 // A class that encapsulates a Matroska file.
 // Implementation
 
@@ -330,9 +330,11 @@ void MatroskaDemux::handleEndOfFile() {
   MatroskaDemuxedTrack** tracks = new MatroskaDemuxedTrack*[numTracks];
 
   HashTable::Iterator* iter = HashTable::Iterator::create(*fDemuxedTracksTable);
-  unsigned i, trackNumber;
+  unsigned i;
+  char const* trackNumber;
+
   for (i = 0; i < numTracks; ++i) {
-    tracks[i] = (MatroskaDemuxedTrack*)iter->next((char const*&)trackNumber);
+    tracks[i] = (MatroskaDemuxedTrack*)iter->next(trackNumber);
   }
   delete iter;
 
