@@ -157,7 +157,7 @@ Boolean MatroskaFileParser::parse() {
 	  break;
 	}
         case DELIVERING_FRAME_WITHIN_BLOCK: {
-	  deliverFrameWithinBlock();
+	  if (!deliverFrameWithinBlock()) return False;
 	  break;
 	}
         case DELIVERING_FRAME_BYTES: {
@@ -865,7 +865,7 @@ void MatroskaFileParser::parseBlock() {
   fCurrentParseState = LOOKING_FOR_BLOCK;
 }
 
-void MatroskaFileParser::deliverFrameWithinBlock() {
+Boolean MatroskaFileParser::deliverFrameWithinBlock() {
 #ifdef DEBUG
   fprintf(stderr, "delivering frame within SimpleBlock or Block\n");
 #endif
@@ -885,7 +885,7 @@ void MatroskaFileParser::deliverFrameWithinBlock() {
       fprintf(stderr, "\n");
 #endif
       restoreSavedParserState(); // so we read from the beginning next time
-      return;
+      return False;
     }
 
     unsigned frameSize = fFrameSizesWithinBlock[fNextFrameNumberToDeliver];
@@ -968,7 +968,7 @@ void MatroskaFileParser::deliverFrameWithinBlock() {
     // Next, deliver (and/or skip) bytes from the input file:
     fCurrentParseState = DELIVERING_FRAME_BYTES;
     setParseState();
-    return;
+    return True;
   } while (0);
 
   // An error occurred.  Try to recover:
@@ -976,6 +976,7 @@ void MatroskaFileParser::deliverFrameWithinBlock() {
   fprintf(stderr, "deliverFrameWithinBlock(): Error parsing data; trying to recover...\n");
 #endif
   fCurrentParseState = LOOKING_FOR_BLOCK;
+  return True;
 }
 
 void MatroskaFileParser::deliverFrameBytes() {
@@ -1129,11 +1130,25 @@ Boolean MatroskaFileParser::parseEBMLVal_unsigned(EBMLDataSize& size, unsigned&
 }
 
 Boolean MatroskaFileParser::parseEBMLVal_float(EBMLDataSize& size, float& result) {
-  unsigned resultAsUnsigned;
-  if (!parseEBMLVal_unsigned(size, resultAsUnsigned)) return False;
+  switch (size.val()) {
+    case 4: {
+      unsigned resultAsUnsigned;
 
-  result = *(float*)&resultAsUnsigned;
-  return True;
+      if (!parseEBMLVal_unsigned(size, resultAsUnsigned)) return False;
+      result = *(float*)&resultAsUnsigned;
+      return True;
+    }
+    case 8: {
+      u_int64_t resultAsU64;
+
+      if (!parseEBMLVal_unsigned64(size, resultAsU64)) return False;
+      result = (float)*(double*)&resultAsU64;
+      return True;
+    }
+    default: {
+      return False;
+    }
+  }
 }
 
 Boolean MatroskaFileParser::parseEBMLVal_string(EBMLDataSize& size, char*& result) {
