@@ -374,6 +374,7 @@ int RTSPClient::openConnection() {
     // We don't yet have a TCP socket (or we used to have one, but it got closed).  Set it up now.
     fInputSocketNum = fOutputSocketNum = setupStreamSocket(envir(), 0);
     if (fInputSocketNum < 0) break;
+    ignoreSigPipeOnSocket(fInputSocketNum); // so that servers on the same host that killed don't also kill us
       
     // Connect to the remote endpoint:
     fServerAddress = *(netAddressBits*)(destAddress.data());
@@ -1219,6 +1220,7 @@ void RTSPClient::responseHandlerForHTTP_GET1(int responseCode, char* responseStr
     // (to the same server & port as before) for the client->server link.  All future output will be to this new socket.
     fOutputSocketNum = setupStreamSocket(envir(), 0);
     if (fOutputSocketNum < 0) break;
+    ignoreSigPipeOnSocket(fOutputSocketNum); // so that servers on the same host that killed don't also kill us
 
     fHTTPTunnelingConnectionIsPending = True;
     int connectResult = connectToServer(fOutputSocketNum, fTunnelOverHTTPPortNum);
@@ -1244,11 +1246,12 @@ void RTSPClient::responseHandlerForHTTP_GET1(int responseCode, char* responseStr
 
   // An error occurred.  Dequeue the pending request(s), and tell them about the error:
   fHTTPTunnelingConnectionIsPending = False;
-  while ((request = fRequestsAwaitingHTTPTunneling.dequeue()) != NULL) {
+  resetTCPSockets(); // do this now, in case an error handler deletes "this"
+  RequestQueue requestQueue(fRequestsAwaitingHTTPTunneling);
+  while ((request = requestQueue.dequeue()) != NULL) {
     handleRequestError(request);
     delete request;
   }
-  resetTCPSockets();
 }
 
 Boolean RTSPClient::setupHTTPTunneling2() {
@@ -1271,11 +1274,8 @@ void RTSPClient::connectionHandler1() {
 
   // Move all requests awaiting connection into a new, temporary queue, to clear "fRequestsAwaitingConnection"
   // (so that "sendRequest()" doesn't get confused by "fRequestsAwaitingConnection" being nonempty, and enqueue them all over again).
-  RequestQueue tmpRequestQueue;
+  RequestQueue tmpRequestQueue(fRequestsAwaitingConnection);
   RequestRecord* request;
-  while ((request = fRequestsAwaitingConnection.dequeue()) != NULL) {
-    tmpRequestQueue.enqueue(request);
-  }
 
   // Find out whether the connection succeeded or failed:
   do {
@@ -1299,11 +1299,11 @@ void RTSPClient::connectionHandler1() {
   } while (0);
 
   // An error occurred.  Tell all pending requests about the error:
+  resetTCPSockets(); // do this now, in case an error handler deletes "this"
   while ((request = tmpRequestQueue.dequeue()) != NULL) {
     handleRequestError(request);
     delete request;
   }
-  resetTCPSockets();
 }
 
 void RTSPClient::incomingDataHandler(void* instance, int /*mask*/) {
@@ -1346,17 +1346,24 @@ void RTSPClient::handleResponseBytes(int newBytesRead) {
       envir().setResultMsg("RTSP response was truncated. Increase \"RTSPClient::responseBufferSize\"");
     }
 
-    // An error occurred while reading our TCP socket.  Call all pending response handlers, indicating this error:
-    RequestRecord* request;
-    while ((request = fRequestsAwaitingResponse.dequeue()) != NULL) {
-      handleRequestError(request);
-      delete request;
-
-      if (newBytesRead > 0) break; // The "RTSP response was truncated" error is applied to the first response handler only
-    }
-
-    if (newBytesRead <= 0) resetTCPSockets();
+    // An error occurred while reading our TCP socket.  Call all pending response handlers, indicating this error.
+    // (However, the "RTSP response was truncated" error is applied to the first response handler only.)
     resetResponseBuffer();
+    RequestRecord* request;
+    if (newBytesRead > 0) { // The "RTSP response was truncated" error
+      if ((request = fRequestsAwaitingResponse.dequeue()) != NULL) {
+	handleRequestError(request);
+	delete request;
+      }
+    } else {
+      RequestQueue requestQueue(fRequestsAwaitingResponse);
+      resetTCPSockets(); // do this now, in case an error handler deletes "this"
+
+      while ((request = requestQueue.dequeue()) != NULL) {
+	handleRequestError(request);
+	delete request;
+      }
+    }
     return;    
   } while (0);
 
@@ -1366,6 +1373,7 @@ void RTSPClient::handleResponseBytes(int newBytesRead) {
   if (fVerbosityLevel >= 1 && newBytesRead > 1) envir() << "Received " << newBytesRead << " new bytes of response data.\n";
   
   unsigned numExtraBytesAfterResponse = 0;
+  Boolean responseSuccess = False; // by default
   do {
     // Data was read OK.  Look through the data that we've read so far, to see if it contains <CR><LF><CR><LF>.
     // (If not, wait for more data to arrive.)
@@ -1400,7 +1408,7 @@ void RTSPClient::handleResponseBytes(int newBytesRead) {
     char const* publicParamsStr = NULL;
     char* bodyStart = NULL;
     unsigned numBodyBytes = 0;
-    Boolean responseSuccess = False; // by default
+    responseSuccess = False;
     do {
       headerDataCopy = new char[responseBufferSize];
       strncpy(headerDataCopy, fResponseBuffer, fResponseBytesAlreadySeen);
@@ -1608,7 +1616,7 @@ void RTSPClient::handleResponseBytes(int newBytesRead) {
     delete foundRequest;
     delete[] headerDataCopy;
     if (numExtraBytesAfterResponse > 0 && numBodyBytes > 0) delete[] bodyStart;
-  } while (numExtraBytesAfterResponse > 0);
+  } while (numExtraBytesAfterResponse > 0 && responseSuccess);
 }
 
 
@@ -1635,6 +1643,14 @@ RTSPClient::RequestQueue::RequestQueue()
   : fHead(NULL), fTail(NULL) {
 }
 
+RTSPClient::RequestQueue::RequestQueue(RequestQueue& origQueue)
+  : fHead(NULL), fTail(NULL) {
+  RequestRecord* request;
+  while ((request = origQueue.dequeue()) != NULL) {
+    enqueue(request);
+  }
+}
+
 RTSPClient::RequestQueue::~RequestQueue() {
   delete fHead;
 }
