@@ -23,12 +23,6 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 #include "Base64.hh"
 #include <GroupsockHelper.hh>
 
-#if defined(__WIN32__) || defined(_WIN32) || defined(_QNX4)
-#else
-#include <signal.h>
-#define USE_SIGNALS 1
-#endif
-
 ////////// RTSPServer implementation //////////
 
 RTSPServer*
@@ -63,9 +57,9 @@ void RTSPServer::addServerMediaSession(ServerMediaSession* serverMediaSession) {
 
   char const* sessionName = serverMediaSession->streamName();
   if (sessionName == NULL) sessionName = "";
-  ServerMediaSession* existingSession
-    = (ServerMediaSession*)(fServerMediaSessions->Add(sessionName, (void*)serverMediaSession));
-  removeServerMediaSession(existingSession); // if any
+  removeServerMediaSession(sessionName); // in case an existing "ServerMediaSession" with this name already exists
+
+  fServerMediaSessions->Add(sessionName, (void*)serverMediaSession);
 }
 
 ServerMediaSession* RTSPServer::lookupServerMediaSession(char const* streamName) {
@@ -84,7 +78,7 @@ void RTSPServer::removeServerMediaSession(ServerMediaSession* serverMediaSession
 }
 
 void RTSPServer::removeServerMediaSession(char const* streamName) {
-  removeServerMediaSession(lookupServerMediaSession(streamName));
+  removeServerMediaSession((ServerMediaSession*)(fServerMediaSessions->Lookup(streamName)));
 }
 
 char* RTSPServer
@@ -198,11 +192,7 @@ RTSPServer::RTSPServer(UsageEnvironment& env,
     fHTTPServerSocket(-1), fHTTPServerPort(0), fClientSessionsForHTTPTunneling(NULL),
     fAuthDB(authDatabase), fReclamationTestSeconds(reclamationTestSeconds),
     fServerMediaSessions(HashTable::create(STRING_HASH_KEYS)) {
-#ifdef USE_SIGNALS
-  // Ignore the SIGPIPE signal, so that clients on the same host that are killed
-  // don't also kill us:
-  signal(SIGPIPE, SIG_IGN);
-#endif
+  ignoreSigPipeOnSocket(ourSocket); // so that clients on the same host that are killed don't also kill us
 
   // Arrange to handle connections from others:
   env.taskScheduler().turnOnBackgroundReadHandling(fRTSPServerSocket,
