@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2011 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2012 Live Networks, Inc.  All rights reserved.
 // A server that supports both RTSP, and HTTP streaming (using Apple's "HTTP Live Streaming" protocol)
 // Implementation
 
@@ -195,7 +195,7 @@ void RTSPServerSupportingHTTPStreaming::RTSPClientSessionSupportingHTTPStreaming
     "#EXT-X-ENDLIST\r\n";
   unsigned const playlistSuffixFmt_maxLen = strlen(playlistSuffixFmt);
 
-  // Figure out the 'target duration' that will produce a paylist that will fit in our response buffer.  (But make it at least 10s.)
+  // Figure out the 'target duration' that will produce a playlist that will fit in our response buffer.  (But make it at least 10s.)
   unsigned const playlistMaxSize = 10000;
   unsigned const mediaFileSpecsMaxSize = playlistMaxSize - (playlistPrefixFmt_maxLen + playlistSuffixFmt_maxLen);
   unsigned const maxNumMediaFileSpecs = mediaFileSpecsMaxSize/playlistMediaFileSpecFmt_maxLen;
@@ -255,5 +255,12 @@ void RTSPServerSupportingHTTPStreaming::RTSPClientSessionSupportingHTTPStreaming
 void RTSPServerSupportingHTTPStreaming::RTSPClientSessionSupportingHTTPStreaming::afterStreaming(void* clientData) {
    RTSPServerSupportingHTTPStreaming::RTSPClientSessionSupportingHTTPStreaming* clientSession
     = (RTSPServerSupportingHTTPStreaming::RTSPClientSessionSupportingHTTPStreaming*)clientData;
-   delete clientSession;
+   // Arrange to delete the 'clientSession' object:
+   if (clientSession->fRecursionCount > 0) {
+     // We're still in the midst of handling a request
+     clientSession->fSessionIsActive = False; // will cause the session to get deleted at the end of handling the request
+   } else {
+     // We're no longer handling a request; delete the 'clientSession' object now:
+     delete clientSession;
+   }
 }
